MiraiWebViewParser class

MiraiWebViewParser is a class that parses the webView widget from JSON.

Constructors

MiraiWebViewParser()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
webView is the type defined for MiraiWebViewParser.
no setter

Methods

getModel(Map<String, dynamic> json) MiraiWebView
getModel method parses the JSON data and returns a MiraiWebView object.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(BuildContext context, MiraiWebView model) Widget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited